@@ -9,6 +9,7 @@ import numpy as np
 import gym
 
 from .dataset import MDPDataset
+from .envs import ChannelFirst
 
 DATA_DIRECTORY = "d3rlpy_data"
 CARTPOLE_URL = "https://www.dropbox.com/s/2tmo7ul00268l3e/cartpole.pkl?dl=1"
@@ -145,7 +146,7 @@ def get_atari(env_name: str) -> Tuple[MDPDataset, gym.Env]:
     try:
         import d4rl_atari  # type: ignore
 
-        env = gym.make(env_name, stack=False)
+        env = ChannelFirst(gym.make(env_name))
         dataset = MDPDataset(discrete_action=True, **env.get_dataset())
         return dataset, env
     except ImportError as e:
@@ -153,3 +154,58 @@ def get_atari(env_name: str) -> Tuple[MDPDataset, gym.Env]:
             "d4rl-atari is not installed.\n"
             "pip install git+https://github.com/takuseno/d4rl-atari"
         ) from e
+
+
+def get_d4rl(env_name: str) -> Tuple[MDPDataset, gym.Env]:
+    """Returns d4rl dataset and envrironment.
+
+    The dataset is provided through d4rl.
+
+    .. code-block:: python
+
+        from d3rlpy.datasets import get_d4rl
+
+        dataset, env = get_d4rl('hopper-medium-v0')
+
+    References:
+        * `Fu et al., D4RL: Datasets for Deep Data-Driven Reinforcement
+          Learning. <https://arxiv.org/abs/2004.07219>`_
+        * https://github.com/rail-berkeley/d4rl
+
+    Args:
+        env_name: environment id of d4rl dataset.
+
+    Returns:
+        tuple of :class:`d3rlpy.dataset.MDPDataset` and gym environment.
+
+    """
+    try:
+        import d4rl  # type: ignore
+
+        env = gym.make(env_name)
+        dataset = env.get_dataset()
+
+        observations = dataset["observations"]
+        actions = dataset["actions"]
+        rewards = dataset["rewards"]
+        terminals = np.logical_and(
+            dataset["terminals"], np.logical_not(dataset["timeouts"])
+        )
+        episode_terminals = np.logical_or(
+            dataset["terminals"], dataset["timeouts"]
+        )
+
+        mdp_dataset = MDPDataset(
+            observations=observations,
+            actions=actions,
+            rewards=rewards,
+            terminals=terminals,
+            episode_terminals=episode_terminals,
+        )
+
+        return mdp_dataset, env
+    except ImportError as e:
+        raise ImportError(
+            "d4rl is not installed.\n"
+            "pip install git+https://github.com/rail-berkeley/d4rl"
+        ) from e
